@@ -63,22 +63,27 @@ var Catalog = function () {
         this.categories.root.elements.push(this.elements[json.name]);
       }
     }
+  }, {
+    key: 'registerMultipleElements',
+    value: function registerMultipleElements(elementArray) {
+      var _this = this;
+
+      elementArray.forEach(function (el) {
+        return _this.registerElement(el);
+      });
+    }
   }, {
     key: 'registerPropertyType',
-    value: function registerPropertyType(propertyType, propertyViewer, propertyEditor) {
-      this.propertyTypes[propertyType] = {
-        type: propertyType,
-        Viewer: propertyViewer,
-        Editor: propertyEditor
-      };
+    value: function registerPropertyType(type, Viewer, Editor) {
+      this.propertyTypes[type] = { type: type, Viewer: Viewer, Editor: Editor };
     }
   }, {
     key: 'registerMultiplePropertyType',
     value: function registerMultiplePropertyType(propertyTypeArray) {
-      var _this = this;
+      var _this2 = this;
 
       propertyTypeArray.forEach(function (el) {
-        return _this.registerPropertyType.apply(_this, _toConsumableArray(el));
+        return _this2.registerPropertyType.apply(_this2, _toConsumableArray(el));
       });
     }
   }, {
@@ -114,10 +119,18 @@ var Catalog = function () {
     }
   }, {
     key: 'registerCategory',
-    value: function registerCategory(name, label) {
+    value: function registerCategory(name, label, childs) {
+      var _this3 = this;
+
       if (this.validateCategory(name, label)) {
         this.categories[name] = { name: name, label: label, categories: [], elements: [] };
         this.categories.root.categories.push(this.categories[name]);
+
+        if (childs && childs.length) {
+          childs.forEach(function (el) {
+            return _this3.addToCategory(name, el);
+          });
+        }
       }
     }
   }, {
@@ -136,21 +149,20 @@ var Catalog = function () {
   }, {
     key: 'categoryHasElement',
     value: function categoryHasElement(categoryName, elementName) {
-      var i = void 0;
-      for (i = 0; i < this.categories[categoryName].elements.length; i++) {
-        if (this.categories[categoryName].elements[i].name === elementName) {
-          return true;
-        }
-      }
-
-      return false;
+      return this.hasCategory(categoryName) && this.categories[categoryName].elements.some(function (el) {
+        return el.name === elementName;
+      });
     }
   }, {
     key: 'validateCategory',
     value: function validateCategory(name, label) {
-      if (name === "") {
+      if (!name) {
+        throw new Error('Category has undefined name');
+      }
+      if (name === '') {
         throw new Error('Category has empty name');
-      } else if (this.categories[name]) {
+      }
+      if (this.hasCategory(name)) {
         throw new Error('Category has already been registered');
       }
 
