@@ -1,6 +1,5 @@
 import * as projectActions from '../actions/project-actions';
 import * as viewer2DActions from '../actions/viewer2d-actions';
-import * as editingActions from '../actions/editing-actions';
 import * as viewer3DActions from '../actions/viewer3d-actions';
 import * as linesActions from '../actions/lines-actions';
 import * as holesActions from '../actions/holes-actions';
@@ -12,7 +11,6 @@ import * as areaActions from '../actions/area-actions';
 export default {
   projectActions,
   viewer2DActions,
-  editingActions,
   viewer3DActions,
   linesActions,
   holesActions,
