@@ -19,7 +19,9 @@ import {
   UPDATE_ZOOM_SCALE,
   TOGGLE_SNAP,
   CHANGE_CATALOG_PAGE,
-  GO_BACK_TO_CATALOG_PAGE
+  GO_BACK_TO_CATALOG_PAGE,
+  THROW_ERROR,
+  THROW_WARNING
 } from '../constants';
 
 export function loadProject(sceneJSON) {
@@ -175,3 +177,17 @@ export function toggleSnap(mask) {
     mask
   };
 }
+
+export function throwError(error) {
+  return {
+    type: THROW_ERROR,
+    error
+  };
+}
+
+export function throwWarning(warning) {
+  return {
+    type: THROW_WARNING,
+    warning
+  };
+}
